#Author-Jordan Oldroyd
#Description-

import adsk.core, adsk.fusion, adsk.cam, traceback, math, os.path

handlers = []
numberOfPulleys = 0

class beltButtonPressedEventHandler(adsk.core.CommandCreatedEventHandler):
    def __init__(self):
        super().__init__()
    def notify(self, args):
        try:
            app = adsk.core.Application.get()
            ui = app.userInterface
            cmd = args.command
            inputs = cmd.commandInputs
            
            # Adding all the different features to the dialog box
            selectionInput1 = inputs.addSelectionInput('selection_1', 
                                                       'Select location of pulley 1', 
                                                       'Select a cylindrical face')
            selectionInput1.setSelectionLimits(1,1)
            selectionInput1.addSelectionFilter('CircularEdges')
            
            valueList = [1.0, 1.5, 2.0, 2.5, 3.0, 3.5, 4.0, 4.5, 5.0]
            inputs.addFloatSliderListCommandInput('slider_1',
                                                  'Pulley 1 Diameter',
                                                  'cm',
                                                  valueList)         
            
            selectionInput2 = inputs.addSelectionInput('selection_2', 
                                                       'Select location of pulley 2', 
                                                       'Select a cylindrical face')
            selectionInput2.setSelectionLimits(1,1)
            selectionInput2.addSelectionFilter('CircularEdges')
            
            inputs.addFloatSliderListCommandInput('slider_2',
                                                  'Pulley 2 Diameter',
                                                  'cm',
                                                  valueList)
            inputs.addTextBoxCommandInput('textBox1', 'Belt Length', '', 2, True)
            
            onInputChanged = beltDialogInputChangedHandler()
            cmd.inputChanged.add(onInputChanged)
            handlers.append(onInputChanged)  
            
        except:
            if ui:
                ui.messageBox('Failed:\n{}'.format(traceback.format_exc()))
                
class beltDialogInputChangedHandler(adsk.core.InputChangedEventHandler):
    def __init__(self):
        super().__init__()
    def notify(self, args):
        app = adsk.core.Application.get()
        ui  = app.userInterface
        try:
            command = args.firingEvent.sender

            diameter1 = None
            diameter2 = None            
            point1 = None
            point2 = None
            
            selectionInput = command.commandInputs.itemById('selection_1')
            if selectionInput.selectionCount > 0:
                selection1 = selectionInput.selection(0).entity
                geom1 = selection1.geometry
                if geom1.objectType == adsk.core.Circle3D.classType():
                    point1 = geom1.center
            selectionInput = command.commandInputs.itemById('selection_2')
            if selectionInput.selectionCount > 0:
                selection2 = selectionInput.selection(0).entity
                geom2 = selection2.geometry
                if geom2.objectType == adsk.core.Circle3D.classType():
                    point2 = geom2.center
            if point1 and point2:
                slider = command.commandInputs.itemById('slider_1')
                diameter1 = slider.valueOne
                slider = command.commandInputs.itemById('slider_2')
                diameter2 = slider.valueOne
                distance = getDistanceBetweenPoints(point1, point2, diameter1 / 2, diameter2 / 2)
                textBox = command.commandInputs.itemById('textBox1')
                textBox.text = str(distance)
            
        except:
            if ui:
                ui.messageBox('Input change failed:\n{}'.format(traceback.format_exc()))
                
################################################### CODE FROM LAB 2 ############################################          

def getDistanceBetweenPoints(point1, point2, radius1, radius2) -> float:          
    try:    
        app = adsk.core.Application.get()
        ui  = app.userInterface
        design = app.activeProduct
        
        lengthBetweenPoints = point1.distanceTo(point2)
        unitsMgr = design.unitsManager
        mainCircumference = math.pi * radius1 * 2      
        adjustedLengthBetweenPulleys = math.sqrt(math.pow(lengthBetweenPoints, 2) + math.pow(radius1 - radius2, 2))
        beltLength = (adjustedLengthBetweenPulleys * 2) + mainCircumference / 2 + (radius2 * math.pi)
        displayBeltLength = unitsMgr.formatInternalValue(beltLength, unitsMgr.defaultLengthUnits, True)
        return displayBeltLength
        
    except:
        if ui:
            ui.messageBox('Get distance failed:\n{}'.format(traceback.format_exc()))
            
class pulleyButtonPressedEventHandler(adsk.core.CommandCreatedEventHandler):
    def __init__(self):
        super().__init__() 
    def notify(self, args):
        try:
            app = adsk.core.Application.get()
            ui  = app.userInterface
            cmd = args.command
            inputs = cmd.commandInputs
            
            # Create selection input
            selectionInput3 = inputs.addSelectionInput('selection_3', 'Select Face', 'Basic select command input')
            selectionInput3.setSelectionLimits(1,1)
            selectionInput3.addSelectionFilter('CylindricalFaces')
            
            # Create dropdown input with test list style
            dropdownInput1 = inputs.addDropDownCommandInput('dropdown1', 'Pulley Type', adsk.core.DropDownStyles.TextListDropDownStyle);
            dropdown1Items = dropdownInput1.listItems
            dropdown1Items.add('Square Tooth', True, '')
            dropdown1Items.add('Round Tooth', False, '')
            
            # Create dropdown input with test list style
            dropdownInput2 = inputs.addDropDownCommandInput('dropdown2', 'Number of Teeth', adsk.core.DropDownStyles.TextListDropDownStyle);
            dropdown2Items = dropdownInput2.listItems
            dropdown2Items.add('12', True, '')
            dropdown2Items.add('13', False, '')
            dropdown2Items.add('14', False, '')
            dropdown2Items.add('15', False, '')
            dropdown2Items.add('16', False, '')
            dropdown2Items.add('17', False, '')
            dropdown2Items.add('18', False, '')
            dropdown2Items.add('19', False, '')
            dropdown2Items.add('20', False, '')
            
            # Run the script for generating the motor mount
            # Connect up to command related events.
            onExecute = pulleyDialogOKEventHandler()
            cmd.execute.add(onExecute)
            handlers.append(onExecute)     

        except:
            if ui:
                ui.messageBox('Failed:\n{}'.format(traceback.format_exc()))
                
                
# Fires when the user presses OK
class pulleyDialogOKEventHandler(adsk.core.CommandEventHandler):
    def __init__(self):
        super().__init__()
    def notify(self, args):
        app = adsk.core.Application.get()
        ui  = app.userInterface
        try:
            cmd = args.firingEvent.sender
            # Get the data and settings from the command inputs.
            faceInput = cmd.commandInputs.itemById('selection_3')
            shaftFace = faceInput.selection(0).entity
            
            dropdownInput1 = cmd.commandInputs.itemById('dropdown1')
            selectedItem1 = dropdownInput1.selectedItem
            selectedType = selectedItem1.name
            
            dropdownInput2 = cmd.commandInputs.itemById('dropdown2')
            selectedItem2 = dropdownInput2.selectedItem
            selectedNumberofTeeth = selectedItem2.name

            # Get diameter of cylindrical face
            geom = shaftFace.geometry
            if geom.objectType == adsk.core.Cylinder.classType():
                diameter = geom.radius   
                if selectedType == 'Round Tooth':
                    design = app.activeProduct
                    rootComp = adsk.fusion.Component.cast(design.rootComponent)
                    #  Hide all bodies and assembly components before generating the geometry for the new pulley component
                    occurences = rootComp.allOccurrences
                    hiddenBodies = []
                    hiddenOccurences = []
                    for o in occurences:
                        if(o.isVisible):
                            o.isVisible = False
                            hiddenOccurences.append(o)
                    for body in rootComp.bRepBodies:
                        if body.isVisible:
                            body.isVisible = False
                            hiddenBodies.append(body)  
                    holeFace = generatePulley(selectedNumberofTeeth, diameter)
                    #  Show all bodies and assembly components we previously hid
                    for o in hiddenOccurences:
                        o.isVisible = True
                    for body in hiddenBodies:
                        body.isVisible = True
                    createAssemblyConstraint(shaftFace, holeFace, False)
                else:   # Trapezoid Tooth was selected
                    faceProxy = CreateTrapGear(selectedNumberofTeeth, diameter * 2)
                    createAssemblyConstraint(shaftFace, faceProxy, True)
                    
            else:        
                ui.messageBox('Geometry error! Expected a cylindrical face.')
        except:
            if ui:
                ui.messageBox('command executed failed:\n{}'.format(traceback.format_exc()))

################################################### CODE FROM LAB 1/2 ############################################

def generatePulley(numberOfTeeth, innerDiameter):
    try:
        app = adsk.core.Application.get()
        ui  = app.userInterface
        design = app.activeProduct
        rootComp = adsk.fusion.Component.cast(design.rootComponent)
        newOcc = rootComp.occurrences.addNewComponent(adsk.core.Matrix3D.create())
        newComp = newOcc.component        
        
        # Assigning other variables, all in cm.
        teethDiameter = 0.2
        distanceBetweenTeeth = 0.5        
        mainCircumference = float(numberOfTeeth) * float(distanceBetweenTeeth)
        mainRadius = mainCircumference / (2 * math.pi)               
        beltWidth = 1.5
        numberOfFlanges = 2
        middleHoleDiameter = innerDiameter
        setScrewExtrudeRadius = 0.8
        setScrewExtrudeLength = 1.25
        setScrewRadius = 0.15
        beltHeight = 0.2
        backFlangeRadius = mainRadius + beltHeight * 2   
        backFlangeWidth = 0.2  
        frontFlangeWidth = backFlangeWidth
        setScrewPlacement = 0.5 * setScrewExtrudeLength + 0.5 * backFlangeWidth
        
        ######## Creating Main Pulley Body  #######
        # Creating Main Circle
        xyPlane = newComp.xYConstructionPlane
        (mainCircleSketch, mainCircle) = createCircleSketch(newComp, xyPlane, 0, 0, 0, mainRadius)        
        # Extruding Main Circle
        mainCircleProfile = mainCircleSketch.profiles.item(0) # Grabbing the profile needed to pass into extrude function
        # Create the Extrude
        extrudes = newComp.features.extrudeFeatures
        # Setting the extrude to a new body
        mainExtrudeInput = extrudes.createInput(mainCircleProfile, adsk.fusion.FeatureOperations.NewBodyFeatureOperation)        
        # Assigning the distance to the extrude
        distanceMainExtrude = adsk.core.ValueInput.createByReal(beltWidth)
        # Putting the distnace value in, False is for symmetric
        mainExtrudeInput.setDistanceExtent(False, distanceMainExtrude)
        # Creating the extrusion
        mainExtrude = extrudes.add(mainExtrudeInput)        
        
        mainExtrudeFace = mainExtrude.endFaces.item(0) # Grabbing the face/edge that will be used later in pattern
        mainExtrudeEdge = mainExtrudeFace.edges.item(0)        


        # Creating Sketch for teeth
        (teethCircleSketch, teethCircle) = createCircleSketch(newComp, xyPlane, mainRadius, 0, 0, teethDiameter)
        # Creating Teeth Cut Extrusion
        teethCircleProfile = teethCircleSketch.profiles.item(0) # Grabbing the profile needed to pass into extrude function
        teethCircleExtrudeInput = extrudes.createInput(teethCircleProfile, adsk.fusion.FeatureOperations.CutFeatureOperation)
        teethCircleExtrudeInput.setDistanceExtent(False, distanceMainExtrude)
        teethCircleExtrude = extrudes.add(teethCircleExtrudeInput)
        
        ##########  Creating Pattern for teeth ########
        # Create the input Entities for the pattern (choosing the teeth extrude body to pattern)
        patternInputEntities = adsk.core.ObjectCollection.create()
        patternInputEntities.add(teethCircleExtrude)
        # Bragging path for the pattern
        patternPath = newComp.features.createPath(mainCircle)
        # establich Quantity and distance
        patternQuantity = adsk.core.ValueInput.createByReal(float(numberOfTeeth))
        patternDistance = adsk.core.ValueInput.createByReal(distanceBetweenTeeth)
        # Create the input for the path pattern
        pathPatterns = newComp.features.pathPatternFeatures
        pathPatternInput = pathPatterns.createInput(patternInputEntities, patternPath, patternQuantity, patternDistance, adsk.fusion.PatternDistanceType.SpacingPatternDistanceType)
        # Create the path pattern
        pathFeature = pathPatterns.add(pathPatternInput)   
        
        
        ###########  Creating the Flanges #######
        if numberOfFlanges > 2 or numberOfFlanges < 0:
            ui.messageBox('You can only have 0, 1, or 2 flanges, but you tried to create % f, please enter in a different value of flanges' %numberOfFlanges )
        
        elif numberOfFlanges == 1 or numberOfFlanges == 2:
            # Create the back flange
            (backFlangeSketch, backFlangeCircle) = createCircleSketch(newComp, xyPlane, 0, 0, 0, backFlangeRadius)
            # Creating the Extrude
            backFlangeCircleProfile = backFlangeSketch.profiles.item(0)
            backFlangeExtrudeInput = extrudes.createInput(backFlangeCircleProfile, adsk.fusion.FeatureOperations.JoinFeatureOperation)
            distancebackFlangeExtrude = adsk.core.ValueInput.createByReal(-1 * backFlangeWidth)            
            backFlangeExtrudeInput.setDistanceExtent(False, distancebackFlangeExtrude)
            backFlangeExtrude = extrudes.add(backFlangeExtrudeInput)


            ####### Rounding the edges of the back flange
            # Finding the edges to use 
            cylinderFace = backFlangeExtrude.sideFaces.item(0)
            backFlangeEdge = cylinderFace.edges.item(0)
            backFlangeEdge2 = cylinderFace.edges.item(1)            
            # create the fillet            
            fillets = newComp.features.filletFeatures
            # Creating a colection for the edges to fillet            
            backFlangeEdgeCollection = adsk.core.ObjectCollection.create()
            backFlangeEdgeCollection.add(backFlangeEdge)
            backFlangeEdgeCollection.add(backFlangeEdge2)
            # Assigning the fillet radius value            
            filletRadius = adsk.core.ValueInput.createByReal(frontFlangeWidth / 2)
            backFlangeFilletInput = fillets.createInput()
            backFlangeFilletInput.addConstantRadiusEdgeSet(backFlangeEdgeCollection, filletRadius, True)
            backFlangeFilletInput.isG2 = False
            backFlangeFilletInput.isRollingBallCorner = True
            backFlangeFillet = fillets.add(backFlangeFilletInput)
            
            
            
            if numberOfFlanges == 2:
                # Grabbing the front face of the main extrude to sketch the second flange                
                (frontFlangeSketch, frontFlangeCircle) = createCircleSketch(newComp, mainExtrude.endFaces.item(0), 0, 0, 0, backFlangeRadius)
                # Creating collection for profiles in the sketch
                frontFlangeProfileCollection = adsk.core.ObjectCollection.create()
                # Grabbing both profiles of the sketch              
                frontFlangeCircleProfile0 = frontFlangeSketch.profiles.item(0)              
                frontFlangeCircleProfile1 = frontFlangeSketch.profiles.item(1)               
                frontFlangeProfileCollection.add(frontFlangeCircleProfile0)  # Passing both profiles into the collection 
                frontFlangeProfileCollection.add(frontFlangeCircleProfile1)
                # Using the collection as the profile input, and making the extrude
                frontFlangeExtrudeInput = extrudes.createInput(frontFlangeProfileCollection, adsk.fusion.FeatureOperations.JoinFeatureOperation)
                distanceFrontFlangeExtrude = adsk.core.ValueInput.createByReal(frontFlangeWidth)            
                frontFlangeExtrudeInput.setDistanceExtent(False, distanceFrontFlangeExtrude)
                frontFlangeExtrude = extrudes.add(frontFlangeExtrudeInput)               
                
                ####### Rounding the edges of the second flange
                cylinderFace2 = frontFlangeExtrude.sideFaces.item(0)
                frontFlangeEdge = cylinderFace2.edges.item(0)
                frontFlangeEdge2 = cylinderFace2.edges.item(1)      
                # create the fillet            
                # Creating a colection for the edges to fillet            
                frontFlangeEdgeCollection = adsk.core.ObjectCollection.create()
                frontFlangeEdgeCollection.add(frontFlangeEdge)
                frontFlangeEdgeCollection.add(frontFlangeEdge2)
                # Assigning the fillet radius value            
                frontFlangeFilletInput = fillets.createInput()
                frontFlangeFilletInput.addConstantRadiusEdgeSet(frontFlangeEdgeCollection, filletRadius, True)
                frontFlangeFilletInput.isG2 = False
                frontFlangeFilletInput.isRollingBallCorner = True
                frontFlangeFillet = fillets.add(frontFlangeFilletInput)

        ########### Creating the extrude to hold the set screw holes. 
        # Creating Sketch        
        (setScrewSketch, setScrewCircle) = createCircleSketch(newComp, xyPlane, 0, 0, 0, setScrewExtrudeRadius)
        # Creating Extrude
        setScrewProfile = setScrewSketch.profiles.item(0)
        setScrewExtrudeInput = extrudes.createInput(setScrewProfile, adsk.fusion.FeatureOperations.JoinFeatureOperation)
        distanceSetScrewExtrude = adsk.core.ValueInput.createByReal(-1 * setScrewExtrudeLength)
        setScrewExtrudeInput.setDistanceExtent(False, distanceSetScrewExtrude)
        setScrewExtrude = extrudes.add(setScrewExtrudeInput) 
  
        ########### Creating the Holes for the Set Screws        
        # Creating first Hole Sketch
        xzPlane = newComp.xZConstructionPlane
        (setScrewHole1Sketch, setScrewHole1Circle) = createCircleSketch(newComp, xzPlane, 0, setScrewPlacement, 0, setScrewRadius)
        # Creating Extrude
        setScrewHole1Profile = setScrewHole1Sketch.profiles.item(0)
        # CutAllOneDirection makes a cut extrude through all in one direction
        setScrewHole1Input = extrudes.createInput(setScrewHole1Profile, adsk.fusion.FeatureOperations.CutFeatureOperation)
        setScrewHole1Input.setAllExtent(0)
        setScrewHole1Extrude = extrudes.add(setScrewHole1Input)

        # Creating Second Hole Sketch 
        yzPlane = newComp.yZConstructionPlane
        (setScrewHole2Sketch, setScrewHole2Circle) = createCircleSketch(newComp, yzPlane, 0, -1 * setScrewPlacement, 0, setScrewRadius)
        # Creating Extrude
        setScrewHole2Profile = setScrewHole2Sketch.profiles.item(0)
        setScrewHole2Input = extrudes.createInput(setScrewHole2Profile, adsk.fusion.FeatureOperations.CutFeatureOperation)
        setScrewHole2Input.setAllExtent(0)
        setScrewHole2Extrude = extrudes.add(setScrewHole2Input)  
        
        ########### Creating the Center Hole #####
        (middleHoleSketch, middleHoleCircle) = createCircleSketch(newComp, xyPlane, 0, 0, 0, middleHoleDiameter)
        # Creating Cut Extrude
        middleHoleProfile = middleHoleSketch.profiles.item(0)
        # CutAllBothDirections will make the cut extrude in both direction
        middleHoleExtrudeInput = extrudes.createInput(middleHoleProfile, adsk.fusion.FeatureOperations.CutFeatureOperation)
        middleHoleExtrudeInput.setAllExtent(2)
        middleHoleExtrude = extrudes.add(middleHoleExtrudeInput)
        
        # Get face of center hole
        holeFace = middleHoleExtrude.faces.item(0)
        faceProxy = holeFace.createForAssemblyContext(newOcc)
        return faceProxy

    except:
        if ui:
            ui.messageBox('Failed:\n{}'.format(traceback.format_exc()))
      
              
        
        
def createCircleSketch(comp, plane, x, y, z, radius):
    app = adsk.core.Application.get()
    ui  = app.userInterface
        
    try:
        sketches = comp.sketches
        circleSketch = sketches.add(plane)
        circles = circleSketch.sketchCurves.sketchCircles
        circle = circles.addByCenterRadius(adsk.core.Point3D.create(x, y, z), radius)
        return (circleSketch, circle)
        
    except:
        if ui:
            ui.messageBox('Failed:\n{}'.format(traceback.format_exc()))
            
            
############################################## CODE FROM LAB 3 ############################################
            
def Import (location, Gear):
    app = adsk.core.Application.get()    
    importManager = app.importManager
    # Get sat import options
    f3dFileName = location
    f3dOptions = importManager.createFusionArchiveImportOptions(f3dFileName)
    # Import sat file to Gear
    importManager.importToTarget(f3dOptions, Gear)
    return Gear.occurrences.item(Gear.occurrences.count-1)


def CreateTrapGear(teethNum, diameter): 
    app = adsk.core.Application.get()
    design = app.activeProduct
    rootComp = adsk.fusion.Component.cast(design.rootComponent)   
    # Get active design
    product = app.activeProduct
    design = adsk.fusion.Design.cast(product)
    # Creates new Component for Import
    filename = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'SquareToothPulley.f3d')
    gearOcc = Import(filename, rootComp)  
    gearComp = gearOcc.component
    parameters = gearComp.parentDesign.allParameters
    # Name all of the parameters in the new pulley according to how many imported pulleys there are
    global numberOfPulleys
    numberOfPulleys += 1
    for parameter in parameters:
        parameter.name += '_' + str(numberOfPulleys)
    ChangeParameters(teethNum, diameter, parameters)    
    # Get and return the face for the shaft hole
    holes = gearComp.features.holeFeatures
    hole = holes.item(0)
    holeFace = hole.faces.item(0)
    faceProxy = holeFace.createForAssemblyContext(gearOcc)
    return faceProxy


def ChangeParameters(teethNum, diameter, parameters):
    global numberOfPulleys
    teeth = parameters.itemByName('teethNum_' + str(numberOfPulleys))
    shaftDiameter = parameters.itemByName('shaftDiameter_' + str(numberOfPulleys))
    teeth.expression = str(teethNum)
    shaftDiameter.expression = str(diameter) + ' cm'
    return 0
    
    
def createAssemblyConstraint(face1, face2, bFlip):
    app = adsk.core.Application.get()
    ui  = app.userInterface
    design = app.activeProduct
    rootComp = adsk.fusion.Component.cast(design.rootComponent)
    try:
        geo1 = adsk.fusion.JointGeometry.createByNonPlanarFace(face1, adsk.fusion.JointKeyPointTypes.StartKeyPoint)
        geo2 = adsk.fusion.JointGeometry.createByNonPlanarFace(face2, adsk.fusion.JointKeyPointTypes.StartKeyPoint)
    
        joints = rootComp.joints
        jointInput = joints.createInput(geo2, geo1)
        jointInput.isFlipped = bFlip
        angle = adsk.core.ValueInput.createByString('0 deg')
        jointInput.angle = angle
        offset = adsk.core.ValueInput.createByString('0 cm')
        jointInput.offset = offset
        jointInput.setAsRigidJointMotion() #(adsk.fusion.JointDirections.CustomJointDirection,rootComp.xYConstructionPlane)
        joints.add(jointInput)
    except:
        if ui:
            ui.messageBox('Create constraint failed:\n{}'.format(traceback.format_exc()))
            
def run(context):
    ui = None
    try:
        app = adsk.core.Application.get()
        ui  = app.userInterface
        
        # Creating the button for the Belt Length Calculator
        # Get the command definitions collection
        commandDefinitions = ui.commandDefinitions
        # Add a button command definition to that collection
        beltButtonDefinition = commandDefinitions.addButtonDefinition('BeltButton',
                                                                      'Belt Length Calculator',
                                                                      'Calculates the length of a belt running around two pulleys of a selected diameter and location',
                                                                      'resources')
        # Grabbing the correct toolbar panel to add the button to
        addinsToolbarPanel = ui.allToolbarPanels.itemById('SolidScriptsAddinsPanel')
        # Adding the belt button to the add-in toolbar panel
        beltButtonControl = addinsToolbarPanel.controls.addCommand(beltButtonDefinition, 'beltButtonControl')
        # Making the button visible without having to use the dropdown
        beltButtonControl.isPromotedByDefault = True
        beltButtonControl.isPromoted = True
        
        # Setting up the handler if the belt button is pressed
        # Calling the class?
        beltButtonPressed = beltButtonPressedEventHandler()
        beltButtonDefinition.commandCreated.add(beltButtonPressed)
        handlers.append(beltButtonPressed)
                
        
        # Doing all the same stuff for the Pulley Generator Button
        pulleyButtonDefinition = commandDefinitions.addButtonDefinition('PulleyButton',
                                                              'Pulley Generator',
                                                              'Creates a pulley and assembles it to a chosen cylinder',
                                                              'resources')
        pulleyButtonControl = addinsToolbarPanel.controls.addCommand(pulleyButtonDefinition, 'pulleyButtonControl')
        pulleyButtonControl.isPromotedByDefault = True
        pulleyButtonControl.isPromoted = True
        
        pulleyButtonPressed = pulleyButtonPressedEventHandler()
        pulleyButtonDefinition.commandCreated.add(pulleyButtonPressed)
        handlers.append(pulleyButtonPressed)

    except:
        if ui:
            ui.messageBox('Failed:\n{}'.format(traceback.format_exc()))

def stop(context):
    ui = None
    try:
        app = adsk.core.Application.get()
        ui  = app.userInterface
        
        # Deleting the belt button
        beltButtonDefinition = ui.commandDefinitions.itemById('BeltButton')
        if beltButtonDefinition:
            beltButtonDefinition.deleteMe()
        addinsToolbarPanel = ui.allToolbarPanels.itemById('SolidScriptsAddinsPanel')
        beltButtonControl = addinsToolbarPanel.controls.itemById('beltButtonControl')
        if beltButtonControl:
            beltButtonControl.deleteMe()

        # Deleting the pulley button
        pulleyButtonDefinition = ui.commandDefinitions.itemById('PulleyButton')
        if pulleyButtonDefinition:
            pulleyButtonDefinition.deleteMe()
        pulleyButtonControl = addinsToolbarPanel.controls.itemById('pulleyButtonControl')
        if pulleyButtonControl:
            pulleyButtonControl.deleteMe()
        
    except:
        if ui:
            ui.messageBox('Failed:\n{}'.format(traceback.format_exc()))
